@@ -16,37 +16,29 @@ r"""
 >>> with pytest.raises(TypeError):
 ...     check_type(Foo("a", [2]))
 
-## `runtime_typecheck` decorator
+## `into_dataclass` function
 
->>> from typing import List
->>> @runtime_typecheck
-... @dataclasses.dataclass
+Recursively constructs dataclass from dict
+
+>>> @dataclasses.dataclass
 ... class Foo:
 ...     a: int
-...     b: List[str]
-
-
->>> foo = Foo(1, ["a"])  # ok
->>> assert isinstance(foo, Foo) # Still, it is an instance of `Foo`
->>> import pytest
->>> with pytest.raises(TypeError):
-...     Foo("a", [])
->>> with pytest.raises(TypeError):
-...     Foo(1, [1, 2])
+>>> @dataclasses.dataclass
+... class Bar:
+...     foo: Foo
+...     b: str
+>>> data = {"foo": {"a": 1}, "b": "foo"}
+>>> bar = into_dataclass(Bar, data)
+>>> assert bar.foo == Foo(**data["foo"]) # field `foo` is instantiated as `Foo`, not dict
 """
 
 from typing import Type, TypeVar
 
 from dataclass_utils.type_checker import check_root as check_type
-from dataclass_utils.type_checker import runtime_typecheck_inner
 from dataclass_utils.into_dataclass import into_dataclass
 from .VERSION import __version__
 
 T = TypeVar("T")
 
 
-def runtime_typecheck(ty: Type[T]) -> Type[T]:
-    return runtime_typecheck_inner(ty)  # type: ignore
-
-
-__all__ = ["runtime_typecheck", "check_type", "into_dataclass", "__version__"]
+__all__ = ["check_type", "into_dataclass", "__version__"]
